#
# spec file for package kf6-knewstuff
#
# Copyright (c) 2024 SUSE LLC
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


%define qt6_version 6.7.0

%define rname knewstuff
# Full KF6 version (e.g. 6.9.0)
%{!?_kf6_version: %global _kf6_version %{version}}
# Last major and minor KF6 version (e.g. 6.0)
%{!?_kf6_bugfix_version: %define _kf6_bugfix_version %(echo %{_kf6_version} | awk -F. '{print $1"."$2}')}
%bcond_without released
Name:           kf6-knewstuff
Version:        6.10.0
Release:        1.1
Summary:        Framework for downloading and sharing additional application data
License:        LGPL-2.1-or-later
URL:            https://www.kde.org
Source:         %{rname}-%{version}.tar.xz
%if %{with released}
Source1:        %{rname}-%{version}.tar.xz.sig
Source2:        frameworks.keyring
%endif
BuildRequires:  doxygen
BuildRequires:  fdupes
BuildRequires:  kf6-extra-cmake-modules >= %{_kf6_bugfix_version}
BuildRequires:  cmake(KF6Archive) >= %{_kf6_bugfix_version}
BuildRequires:  cmake(KF6Attica) >= %{_kf6_bugfix_version}
BuildRequires:  cmake(KF6Config) >= %{_kf6_bugfix_version}
BuildRequires:  cmake(KF6CoreAddons) >= %{_kf6_bugfix_version}
BuildRequires:  cmake(KF6I18n) >= %{_kf6_bugfix_version}
BuildRequires:  cmake(KF6Package) >= %{_kf6_bugfix_version}
BuildRequires:  cmake(KF6Syndication) >= %{_kf6_bugfix_version}
BuildRequires:  cmake(KF6WidgetsAddons) >= %{_kf6_bugfix_version}
BuildRequires:  cmake(Qt6Core) >= %{qt6_version}
BuildRequires:  cmake(Qt6Gui) >= %{qt6_version}
BuildRequires:  cmake(Qt6Qml) >= %{qt6_version}
BuildRequires:  cmake(Qt6Quick) >= %{qt6_version}
BuildRequires:  cmake(Qt6QuickWidgets) >= %{qt6_version}
BuildRequires:  cmake(Qt6ToolsTools) >= %{qt6_version}
BuildRequires:  cmake(Qt6UiPlugin) >= %{qt6_version}
BuildRequires:  cmake(Qt6Widgets) >= %{qt6_version}
BuildRequires:  cmake(Qt6Xml) >= %{qt6_version}

%description
The KNewStuff library implements collaborative data sharing for
applications. It uses libattica to support the Open Collaboration Services
specification.

%package -n libKF6NewStuffCore6
Summary:        Framework for downloading and sharing additional application data
Requires:       kf6-knewstuff >= %{version}

%description -n libKF6NewStuffCore6
The KNewStuff library implements collaborative data sharing for
applications. It uses libattica to support the Open Collaboration Services
specification.

%package -n libKF6NewStuffWidgets6
Summary:        Framework for downloading and sharing additional application data

%description -n libKF6NewStuffWidgets6
The KNewStuff library implements collaborative data sharing for
applications. It uses libattica to support the Open Collaboration Services
specification.

%package imports
Summary:        Framework for downloading and sharing additional application data
Requires:       kf6-kirigami-imports >= %{_kf6_bugfix_version}

%description imports
The KNewStuff library implements collaborative data sharing for
applications. It uses libattica to support the Open Collaboration Services
specification.

%package core-devel
Summary:        Framework for downloading and sharing additional application data
Requires:       libKF6NewStuffCore6 = %{version}
Requires:       cmake(KF6Attica) >= %{_kf6_bugfix_version}
Requires:       cmake(KF6CoreAddons) >= %{_kf6_bugfix_version}

%description core-devel
The KNewStuff library implements collaborative data sharing for
applications. It uses libattica to support the Open Collaboration Services
specification. Development files.

%package devel
Summary:        Framework for downloading and sharing additional application data
Requires:       kf6-knewstuff-core-devel = %{version}
Requires:       libKF6NewStuffWidgets6 = %{version}
Requires:       cmake(Qt6Widgets) >= %{qt6_version}

%description devel
The KNewStuff library implements collaborative data sharing for
applications. It uses libattica to support the Open Collaboration Services
specification. Development files.

%lang_package -n libKF6NewStuffCore6

%prep
%autosetup -p1 -n %{rname}-%{version}

%build
%cmake_kf6 -DBUILD_QCH:BOOL=TRUE

%kf6_build

%install
%kf6_install

%fdupes %{buildroot}

%find_lang knewstuff6

%ldconfig_scriptlets -n libKF6NewStuffCore6
%ldconfig_scriptlets -n libKF6NewStuffWidgets6

%files
%{_kf6_applicationsdir}/org.kde.knewstuff-dialog6.desktop
%{_kf6_bindir}/knewstuff-dialog6
%{_kf6_debugdir}/knewstuff.categories
%{_kf6_debugdir}/knewstuff.renamecategories

%files -n libKF6NewStuffCore6
%license LICENSES/*
%doc README.md
%{_kf6_libdir}/libKF6NewStuffCore.so.*

%files -n libKF6NewStuffWidgets6
%{_kf6_libdir}/libKF6NewStuffWidgets.so.*

%files imports
%{_kf6_qmldir}/org/kde/newstuff/

%files core-devel
%doc %{_kf6_qchdir}/KF6NewStuffCore.*
%{_kf6_includedir}/KNewStuffCore/
%{_kf6_cmakedir}/KF6NewStuffCore/
%{_kf6_libdir}/libKF6NewStuffCore.so

%files devel
%doc %{_kf6_qchdir}/KF6NewStuffWidgets.*
%{_kf6_cmakedir}/KF6NewStuff/
%{_kf6_includedir}/KNewStuff/
%{_kf6_includedir}/KNewStuffWidgets/
%{_kf6_libdir}/libKF6NewStuffWidgets.so
%{_kf6_plugindir}/designer/knewstuff6widgets.so

%files -n libKF6NewStuffCore6-lang -f knewstuff6.lang

%changelog
* Thu Jan  9 2025 Christophe Marin <christophe@krop.fr>
- Update to 6.10.0
  * New feature release
  * For more details please see:
  * https://kde.org/announcements/frameworks/6/6.10.0
- Changes since 6.9.0:
  * Update dependency version to 6.10.0
  * Remove unimplemented methods
  * Remove Q_EMIT for non-signal method call
  * Add trailing comma to enum
  * Fix compile on macos
  * Update version to 6.10.0
* Sun Dec  8 2024 Christophe Marin <christophe@krop.fr>
- Update to 6.9.0
  * New feature release
  * For more details please see:
  * https://kde.org/announcements/frameworks/6/6.9.0
- Changes since 6.8.0:
  * Update dependency version to 6.9.0
  * transaction: use cache2 not the deprecated legacy cache
  * do not finish the transaction before it actually did anything (kde#496551)
  * cache: become a facade for Cache2
  * Use isEmpty() vs count() > 0
  * Bump KF and QT versions in ecm_set_disabled_deprecation_versions
  * providerbase: split done signal from loaded signal
  * staticxmlprovider: remove unused member
  * ci: add Alpine/musl job
  * ResultsStream: Restore the providers upon ::fetchMore
  * fixup! the grand API refactor of 2024
  * the grand API refactor of 2024
  * Port test away from deprecated API
  * Add missing KNEWSTUFFCORE_BUILD_DEPRECATED_SINCE
  * fix random timeouts in attica test
  * transaction: deprecate ambiguous install function
  * Update version to 6.9.0
* Mon Nov  4 2024 Christophe Marin <christophe@krop.fr>
- Update to 6.8.0
  * New feature release
  * For more details please see:
  * https://kde.org/announcements/frameworks/6/6.8.0
- Changes since 6.7.0:
  * Update dependency version to 6.8.0
  * make sure the action's dialog closes (kde#492998)
  * put qnetworkreplys in a self-aborting unique_ptr
  * parent the xml loader's httpjob
  * filecopyworker: try to gracefully quit the thread. then terminate it
  * Update version to 6.8.0
* Mon Oct  7 2024 Christophe Marin <christophe@krop.fr>
- Update to 6.7.0
  * New feature release
  * For more details please see:
  * https://kde.org/announcements/frameworks/6/6.7.0
- Changes since 6.6.0:
  * Update dependency version to 6.7.0
  * Don't emit twice slotEntryChanged
  * qtquick: make sort/filter buttons like Discover/kcms
  * Update version to 6.7.0
* Sat Sep  7 2024 Christophe Marin <christophe@krop.fr>
- Update to 6.6.0
  * New feature release
  * For more details please see:
  * https://kde.org/announcements/frameworks/6/6.6.0
- Changes since 6.5.0:
  * Update version to 6.6.0
  * add especially crappy magic to deal with transient parents in actions (kde#491083)
  * make staticxmlprovider (more) reentrant
  * make AtticaProvider reentrant
  * typos--
* Mon Aug  5 2024 Christophe Marin <christophe@krop.fr>
- Update to 6.5.0
  * New feature release
  * For more details please see:
  * https://kde.org/announcements/frameworks/6/6.5.0
- Changes since 6.4.0:
  * Update dependency version to 6.5.0
  * support new version field on DownloadLinkInformation
  * QML: Use some better property types
  * EntryDetails.qml: Qualify newStuffModel, use downloadItemId (kde#483659)
  * Update version to 6.5.0
  * Use KPackageJob::update instead of ::install
* Tue Jul  9 2024 Christophe Marin <christophe@krop.fr>
- Update to 6.4.0
  * New feature release
  * For more details please see:
  * https://kde.org/announcements/frameworks/6/6.4.0
- Changes since 6.3.0:
  * Remove Icons view
  * Remove user-facing view switcher
  * Use Tiles view by default
  * Add punctuation to warning
  * BigPreviewDelegate: Fix "Update" action
  * Action: Remove dead code
  * gitignore: add VS Code dir
* Wed Jun  5 2024 Christophe Marin <christophe@krop.fr>
- Update to 6.3.0
  * New feature release
  * For more details please see:
  * https://kde.org/announcements/frameworks/6/6.3.0/
- Too many changes to list here.
* Mon May  6 2024 Christophe Marin <christophe@krop.fr>
- Update to 6.2.0
  * New feature release
  * For more details please see:
  * https://kde.org/announcements/gear/6.2.0/
- Too many changes since 6.1.0, only listing bugfixes:
  * Show header warning message framelessly (kde#485464)
  * DownloadItemsSheet: use alternating background colors for legibility (kde#483724)
* Fri Apr  5 2024 Christophe Marin <christophe@krop.fr>
- Update to 6.1.0
  * New feature release
- Changes since 6.0.0:
  * update version for new release
  * Add extra ksnrc key to indicate the safety of installation
  * Use Continue/Cancel style of question for overwrite dialog
  * Change default sorting of entries to "Most Downloads"
  * resultsstream: Delay the entry loading into the event look (kde#473472)
  * resultsstream: handle query results assertively
  * resultsstream: Allow for the members to be constant
  * Unify default sizes (kde#482604)
  * Fix the "working..." overlay for item installation (kde#483108)
  * Remove the last uses of Qt5Compat.GraphicalEffects
  * Refresh visible entry on uninstall (kde#476152)
  * [qtquick/action] Add API to set transient parent for dialog (kde#479816)
  * Fix link list dialog for installation button (kde#482349)
  * Set questionAsker implicit sizes, set maxWidth to dialog width (kde#480338)
- Drop patch, merged upstream:
  * 0001-Fix-link-list-dialog-for-installation-button.patch
* Wed Mar 13 2024 Christophe Marin <christophe@krop.fr>
- Add upstream fix (kde#482349):
  * 0001-Fix-link-list-dialog-for-installation-button.patch
* Wed Feb 21 2024 Fabian Vogt <fabian@ritter-vogt.de>
- Update to 6.0.0
  * New bugfix release
  * Release announcement not available yet
- Changes since 5.249.0:
  * QuickEngine: Fix Installed and Updateable filters
  * update version for new release
  * delegates: Fix thumbnail placeholder icon position
  * update version for new release
* Wed Jan 31 2024 Fabian Vogt <fabian@ritter-vogt.de>
- Update to 5.249.0 (6.0 RC 2):
  * New bugfix release
  * For more details see https://kde.org/announcements/megarelease/6/rc2/
* Mon Jan 15 2024 Fabian Vogt <fabian@ritter-vogt.de>
- Update to 5.248.0 (6.0 RC 1)
  * For more details please see:
    https://kde.org/announcements/megarelease/6/rc1/
* Sat May 27 2023 Christophe Marin <christophe@krop.fr>
- Init kf6-knewstuff
